==> nextcloud-app-mail-0.7.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sv.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Loading accounts …" : "Laddar konton ...",
    "Error while loading the accounts." : "Fel vid inläsning av konton.",
    "Error while loading the selected account." : "Fel vid inläsning av valt konto.",
    "Can not load this folder." : "Kan inte ladda denna mapp.",
    "Loading {folder}" : "Laddar {folder}",
    "Searching for {query}" : "Söker efter {query}",
    "Error while deleting message." : "Fel vid radering av  meddelande.",
    "Forwarded message" : "Vidarebefordrat meddelande",
    "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
    "Attachments saved to Files." : "Bilagorna har sparats till filer.",
    "Attachment saved to Files." : "Bilagan har sparats till filer.",
    "Error while saving attachments to Files." : "Ett fel uppstod när bilagorna sparades till filer.",
    "Error while saving attachment to Files." : "Ett fel uppstod när bilagan sparades till filer.",
    "Message flag could not be set." : "Meddelandeflaggan kunde inte ställas in.",
    "Could not move message." : "Kunde inte flytta meddelande.",
    "Invalid account" : "Felaktigt konto",
    "Invalid folder" : "Felaktig mapp",
    "Error while creating the account: " : "Fel när kontot skulle skapas:",
    "Unknown error" : "Okänt fel",
    "All inboxes" : "alla inkorgar",
    "you" : "du",
    "Send message to {email}" : "Skicka meddelande till {email}",
    "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Vi kunde inte ladda {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
    "We couldn’t load your message" : "Vi kunde inte ladda ditt meddelande",
    "Unable to load the desired message" : "Kan ej ladda önskat meddelande",
    "There was a problem loading the message" : "Det blev ett problem när vi skulle ladda meddelandet",
    "{from}\n{subject}" : "{från}\n{ämne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Show all folders" : "Visa alla kataloger",
    "Collapse folders" : "Dölj mappar",
    "Error while deleting account." : "Fel vid radering av konto.",
    "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
    "An error occurred while uploading {fname}" : "Ett fel inträffade när {fname} laddades upp",
    "Reply" : "Svara",
    "Send" : "Skicka",
    "Sending …" : "Skickar ...",
    "Message sent!" : "Meddelande skickat!",
    "Server error" : "Serverfel",
    "An unknown error occurred" : "Ett okänt fel uppstod",
    "Opening HTML drafts is not supported yet." : "Att öppna HTML-utkast stöds inte än.",
    "Draft saved!" : "Utkast sparat!",
    "No writable calendars found" : "Inga skrivbara kalendrar hittade",
    "Error while importing the calendar event" : "Fel vid import av kalenderhändelse",
    "Error while downloading calendar event" : "Fel vid nedladdning av kalenderhändelse",
    "Error while loading messages." : "Fel vid inläsning av meddelanden.",
    "Error while refreshing messages." : "Fel när meddelande uppdaterades.",
    "Setting up your account" : "Sätter upp ditt konto",
    "Inbox" : "Inkorg",
    "Sent" : "Skickat",
    "Drafts" : "Utkast",
    "Archive" : "Arkiv",
    "Trash" : "Papperskorgen",
    "Junk" : "Skräp",
    "All" : "Alla",
    "Favorites" : "Favoriter",
    "Creating account failed: " : "Misslyckades att skapa kontot:",
    "Auto detect failed. Please use manual mode." : "Automatisk detektering misslyckades. Vänligen använd manuellt läge.",
    "Delete permanently" : "Radera permanent",
    "& others" : "& andra",
    "Error loading message" : "Fel vid inläsning av meddelande",
    "Settings" : "Inställningar",
    "Forwarding to %s" : "Vidarebefordrar till %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
    "Redirect" : "Omdirigera",
    "The link leads to %s" : "Länken pekar mot %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Om du inte vill besöka denna sidan så kan du gå tillbaka till <a href=\"%s\">Mail</a>",
    "Continue to %s" : "Fortsätt till %s",
    "Delete account" : "Radera konto",
    "Try again" : "Försök igen",
    "New message" : "Nytt meddelande",
    "Account Settings" : "Kontoinställningar",
    "Aliases" : "Alias",
    "Mail address" : "E-postadress",
    "Display Name" : "Visningsnamn",
    "Save" : "Spara",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Speed up your Mail experience with these quick shortcuts." : "Snabba upp din E-post-upplevelse med dessa genvägar.",
    "Compose new message" : "Skapa nytt meddelande",
    "Newer message" : "Nyare meddelande",
    "Older message" : "Äldre meddelande",
    "Toggle star" : "Växla stjärna",
    "Toggle unread" : "Växla oläst",
    "Delete" : "Ta bort",
    "Search" : "Sök",
    "Refresh" : "Uppdatera",
    "Connect your mail account" : "Anslut ditt e-postkonto",
    "Name" : "Namn",
    "Mail Address" : "E-postadress",
    "Password" : "Lösenord",
    "Manual configuration" : "Manuellt konfiguration",
    "IMAP Host" : "IMAP-värd",
    "IMAP security" : "IMAP säkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "Användare",
    "IMAP Password" : "IMAP-lösenord",
    "SMTP Host" : "SMTP Host",
    "SMTP security" : "SMTP-säkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-användare",
    "SMTP Password" : "SMTP-lösenord",
    "Connect" : "Anslut",
    "from" : "Från",
    "to" : "till",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Ämne",
    "Save all to Files" : "Spara allt till dina filer",
    "Add mail account" : "Lägg till e-postkonto",
    "No search results for" : "Inga sökresultat hittades för",
    "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
    "Show images from this sender" : "Visa bilder från denna avsändare",
    "Forward" : "Vidarebefodra",
    "Add attachment" : "Lägg till bilaga",
    "Add from Files" : "Lägg till från filer",
    "Import into calendar" : "Importera till kalender",
    "Download attachment" : "Ladda ned bilaga",
    "Save to Files" : "Spara fil till dina filer"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/sv.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Loading accounts" : "Laddar konton",
    "Error while loading the accounts." : "Fel vid inläsning av konton.",
    "Error while loading the selected account." : "Fel vid inläsning av valt konto.",
    "Can not load this folder." : "Kan inte ladda denna mapp.",
    "Searching for {query}" : "Söker efter {query}",
    "Error while deleting message." : "Fel vid radering av  meddelande.",
    "Forwarded message" : "Vidarebefordrat meddelande",
    "Choose a folder to store the attachment in" : "Välj en mapp att spara den bifogade filen i",
    "Attachments saved to Files." : "Bilagorna har sparats till filer.",
    "Attachment saved to Files." : "Bilagan har sparats till filer.",
    "Error while saving attachments to Files." : "Ett fel uppstod när bilagorna sparades till filer.",
    "Error while saving attachment to Files." : "Ett fel uppstod när bilagan sparades till filer.",
    "Message flag could not be set." : "Meddelandeflaggan kunde inte ställas in.",
    "Could not move message." : "Kunde inte flytta meddelande.",
    "Invalid account" : "Felaktigt konto",
    "Invalid folder" : "Felaktig mapp",
    "Error while creating the account: " : "Fel när kontot skulle skapas:",
    "Unknown error" : "Okänt fel",
    "All inboxes" : "alla inkorgar",
    "you" : "du",
    "Send message to {email}" : "Skicka meddelande till {email}",
    "Could not load {tag}{name}{endtag}" : "Kunde inte ladda {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Vi kunde inte ladda {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det blev ett problem när vi skulle ladda {tag}{name}{endtag}",
    "We couldn’t load your message" : "Vi kunde inte ladda ditt meddelande",
    "Unable to load the desired message" : "Kan ej ladda önskat meddelande",
    "There was a problem loading the message" : "Det blev ett problem när vi skulle ladda meddelandet",
    "{from}\n{subject}" : "{från}\n{ämne}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nytt meddelande \nfrån {from}","%n nya meddelanden \nfrån {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "Show all folders" : "Visa alla kataloger",
    "Collapse folders" : "Dölj mappar",
    "Error while deleting account." : "Fel vid radering av konto.",
    "Choose a file to add as attachment" : "Välj en fil att lägga som bilaga",
    "An error occurred while uploading {fname}" : "Ett fel inträffade när {fname} laddades upp",
    "Reply" : "Svara",
    "Send" : "Skicka",
    "Sending …" : "Skickar ...",
    "Message sent!" : "Meddelande skickat!",
    "Server error" : "Serverfel",
    "An unknown error occurred" : "Ett okänt fel uppstod",
    "Opening HTML drafts is not supported yet." : "Att öppna HTML-utkast stöds inte än.",
    "Draft saved!" : "Utkast sparat!",
    "No writable calendars found" : "Inga skrivbara kalendrar hittade",
    "Error while importing the calendar event" : "Fel vid import av kalenderhändelse",
    "Error while downloading calendar event" : "Fel vid nedladdning av kalenderhändelse",
    "Error while loading messages." : "Fel vid inläsning av meddelanden.",
    "Error while refreshing messages." : "Fel när meddelande uppdaterades.",
    "Setting up your account" : "Sätter upp ditt konto",
    "Inbox" : "Inkorg",
    "Sent" : "Skickat",
    "Drafts" : "Utkast",
    "Archive" : "Arkiv",
    "Trash" : "Papperskorgen",
    "Junk" : "Skräp",
    "All" : "Alla",
    "Favorites" : "Favoriter",
    "Auto detect failed. Please use manual mode." : "Automatisk detektering misslyckades. Vänligen använd manuellt läge.",
    "Creating account failed: " : "Misslyckades att skapa kontot:",
    "Delete permanently" : "Radera permanent",
    "& others" : "& andra",
    "Error loading message" : "Fel vid inläsning av meddelande",
    "Settings" : "Inställningar",
    "Forwarding to %s" : "Vidarebefordrar till %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klicka här om du inte blir omdirigerad inom några sekunder.",
    "Redirect" : "Omdirigera",
    "The link leads to %s" : "Länken pekar mot %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Om du inte vill besöka denna sidan så kan du gå tillbaka till <a href=\"%s\">Mail</a>",
    "Continue to %s" : "Fortsätt till %s",
    "Delete account" : "Radera konto",
    "Try again" : "Försök igen",
    "New message" : "Nytt meddelande",
    "Account Settings" : "Kontoinställningar",
    "Aliases" : "Alias",
    "Mail address" : "E-postadress",
    "Display Name" : "Visningsnamn",
    "Save" : "Spara",
    "Keyboard shortcuts" : "Tangentbordsgenvägar",
    "Speed up your Mail experience with these quick shortcuts." : "Snabba upp din E-post-upplevelse med dessa genvägar.",
    "Compose new message" : "Skapa nytt meddelande",
    "Newer message" : "Nyare meddelande",
    "Older message" : "Äldre meddelande",
    "Toggle star" : "Växla stjärna",
    "Toggle unread" : "Växla oläst",
    "Delete" : "Ta bort",
    "Search" : "Sök",
    "Refresh" : "Uppdatera",
    "Connect your mail account" : "Anslut ditt e-postkonto",
    "Name" : "Namn",
    "Mail Address" : "E-postadress",
    "Password" : "Lösenord",
    "Manual configuration" : "Manuellt konfiguration",
    "IMAP Host" : "IMAP-värd",
    "IMAP security" : "IMAP säkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP-port",
    "IMAP User" : "Användare",
    "IMAP Password" : "IMAP-lösenord",
    "SMTP Host" : "SMTP Host",
    "SMTP security" : "SMTP-säkerhet",
    "SMTP Port" : "SMTP-port",
    "SMTP User" : "SMTP-användare",
    "SMTP Password" : "SMTP-lösenord",
    "Connect" : "Anslut",
    "from" : "Från",
    "to" : "till",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Ämne",
    "Save all to Files" : "Spara allt till dina filer",
    "Add mail account" : "Lägg till e-postkonto",
    "No search results for" : "Inga sökresultat hittades för",
    "The images have been blocked to protect your privacy." : "Bilderna har blockerats av säkerhetsskäl.",
    "Show images from this sender" : "Visa bilder från denna avsändare",
    "Forward" : "Vidarebefodra",
    "No messages in this folder!" : "Inga meddelanden i denna mappen!",
    "Upload attachment" : "Ladda upp bilaga",
    "Add attachment from Files" : "Lägg till bilaga från Filer",
    "Import into calendar" : "Importera till kalender",
    "Download attachment" : "Ladda ned bilaga",
    "Save to Files" : "Spara fil till dina filer"
},
"nplurals=2; plural=(n != 1);");
